.. _developers-guide-index:

=================
Developer's Guide
=================

.. toctree::
    :maxdepth: 2
    
    Taurus 3.x to Taurus 4.x migration guide <taurus3to4>
    Development guidelines <coding_guide>
    Creating GUIs with the TaurusGUI framework <taurusgui_newgui>
    Designer tutorial <designer_tutorial>
    Icon guide <icon_guide>
    Core tutorial <core_tutorial>
    Taurus Custom Settings <tauruscustomsettings>
    Examples <examples>
    API <api/taurus>
    All Classes <api/taurus_AllClasses.rst>
    
